@@ -1,5 +1,5 @@
-# Copyright 2020-2021 AstroLab Software
-# Author: Marco Leoni, Julien Peloton
+# Copyright 2020-2022 AstroLab Software
+# Author: Marco Leoni, E.O. Ishida, Julien Peloton
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -15,7 +15,7 @@
 import numpy as np
 
 from scipy.optimize import least_squares
-from scipy.stats import chisquare
+from sklearn.metrics import mean_squared_error
 
 
 def delta_t(time_index: np.array) -> np.array:
@@ -116,8 +116,8 @@ def fit_sigmoid(time: np.array, flux: np.array) -> list:
     return result.x
 
 
-def compute_chi_square(f_obs: np.array, f_exp: np.array) -> float:
-    """ Compute chisquare
+def compute_mse(f_obs: np.array, f_exp: np.array) -> float:
+    """ Compute mean squared error.
 
     Parameters
     ----------
@@ -128,10 +128,10 @@ def compute_chi_square(f_obs: np.array, f_exp: np.array) -> float:
 
     Returns
     -------
-    test_chi[0]: float
-        chi_square between fitted and observed
+    test_mse: float
+        mse between fitted and observed
     """
 
-    test_chi = chisquare(f_obs, f_exp,)
+    test_mse = mean_squared_error(f_obs, f_exp,)
 
-    return test_chi[0]
+    return test_mse
